@@ -11,7 +11,6 @@ from itertools import chain
 
 from sphinx.util import logging
 import re
-import six
 
 from docutils import nodes
 
@@ -52,10 +51,7 @@ except ImportError:
     except ImportError:
         from ordereddict import OrderedDict
 
-if six.PY2:
-    from itertools import imap as map
-
-__version__ = '0.2.0'
+__version__ = '0.2.2'
 
 __author__ = "Philipp S. Sommer"
 
@@ -188,7 +184,7 @@ class AutosummaryDocumenter(object):
         registry = get_documenters(self.env.app)
 
         for (mname, member, isattr) in self.filter_members(members, want_all):
-            classes = [cls for cls in six.itervalues(registry)
+            classes = [cls for cls in registry.values()
                        if cls.can_document_member(member, mname, isattr, self)]
             if not classes:
                 # don't know how to document this member
@@ -203,6 +199,17 @@ class AutosummaryDocumenter(object):
             documenter = classes[-1](self.directive, full_mname, self.indent)
             memberdocumenters.append((documenter,
                                       members_check_module and not isattr))
+
+        member_order = (
+            self.options.member_order or self.env.config.autodoc_member_order
+        )
+        try:
+            memberdocumenters = self.sort_members(
+                memberdocumenters, member_order
+            )
+        except AttributeError:  # sphinx<3.0
+            pass
+
         documenters = OrderedDict()
         for e in memberdocumenters:
             section = self.member_sections.get(
@@ -210,6 +217,8 @@ class AutosummaryDocumenter(object):
             if self.env.app:
                 e[0].parse_name()
                 e[0].import_object()
+                if members_check_module and not e[0].check_module():
+                    continue
                 user_section = self.env.app.emit_firstresult(
                     'autodocsumm-grouper', self.objtype, e[0].object_name,
                     e[0].object, section, self.object)
@@ -372,7 +381,7 @@ class CallableDataDocumenter(DataDocumenter):
 
         doc = []
         for docstring in docstrings:
-            if not isinstance(docstring, six.text_type):
+            if not isinstance(docstring, str):
                 docstring = force_decode(docstring, encoding)
             doc.append(prepare_docstring(docstring, ignore))
 
@@ -416,7 +425,7 @@ class CallableAttributeDocumenter(AttributeDocumenter):
 
         doc = []
         for docstring in docstrings:
-            if not isinstance(docstring, six.text_type):
+            if not isinstance(docstring, str):
                 docstring = force_decode(docstring, encoding)
             doc.append(prepare_docstring(docstring, ignore))
 
@@ -527,8 +536,8 @@ class AutoDocSummDirective(SphinxDirective):
         except (KeyError, ValueError, TypeError) as exc:
             # an option is either unknown or has a wrong type
             logger.error(
-                f'An option to {self.name} is either unknown or has an invalid '
-                f'value: {exc}',
+                'An option to %s is either unknown or has an invalid '
+                'value: %s', self.name, exc,
                 location=(self.env.docname, lineno))
             return []
 
